@@ -14,4 +14,4 @@ macro_rules! dprint {
 }
 
 #[cfg(feature = "derive")]
-pub use point_derive::*;
+pub use fraco_point_derive::*;
